package kqueue

  1. Overview
  2. Docs

0.7.0

  • Use kqueuex if KQUEUE_CLOEXEC is defined.
  • Allow calling fold for events.
  • Simpler interface for adding events that avoids allocating a record/callback.
  • Remove intermediate event type from Event_list module.
  • Add simple tests that hook into dune runtest.
  • Add EVFILT_USER and EVFILT_SIGNAL

0.6.0

  • Zero out the backing array when first creating an event list
  • Track the number of events specified by the user in the event list

0.5.0

  • Remove dependency on ppx_optcomp

0.4.0

  • Use conditional compilation to avoid using NOTE_OOB, NOTE_SIGNAL on FreeBSD (#18, @DavidAlphaFox)
  • Disable EVFILT_EXCEPT on OpenBSD (#18, @DavidAlphaFox)

0.3.0

  • Support EVFILT_USER

0.2.0

  • Remove the use of ctypes
  • Limit support to 64 bit systems
  • Add pre-defined constants for filter flags

0.1.0

  • Initial version of kqueue-ml